@@ -38,15 +38,15 @@ class Document(object):
     def add_heading(self, text='', level=1):
         """
         Return a heading paragraph newly added to the end of the document,
-        populated with *text* and having the heading paragraph style
-        determined by *level*. If *level* is 0, the style is set to
-        ``'Title'``. If *level* is 1 (or not present), ``'Heading1'`` is used.
-        Otherwise the style is set to ``'Heading{level}'``. If *level* is
-        outside the range 0-9, |ValueError| is raised.
+        containing *text* and having its paragraph style determined by
+        *level*. If *level* is 0, the style is set to `Title`. If *level* is
+        1 (or omitted), `Heading 1` is used. Otherwise the style is set to
+        `Heading {level}`. Raises |ValueError| if *level* is outside the
+        range 0-9.
         """
         if not 0 <= level <= 9:
             raise ValueError("level must be in range 0-9, got %d" % level)
-        style = 'Title' if level == 0 else 'Heading%d' % level
+        style = 'Title' if level == 0 else 'Heading %d' % level
         return self.add_paragraph(text, style)
 
     def add_page_break(self):
@@ -96,15 +96,14 @@ class Document(object):
         """
         return self._document_part.add_section(start_type)
 
-    def add_table(self, rows, cols, style='LightShading-Accent1'):
+    def add_table(self, rows, cols, style='Light Shading Accent 1'):
         """
         Add a table having row and column counts of *rows* and *cols*
         respectively and table style of *style*. If *style* is |None|, a
         table with no style is produced.
         """
         table = self._document_part.add_table(rows, cols)
-        if style:
-            table.style = style
+        table.style = style
         return table
 
     @property
